#!/bin/sh
#
# Coyote init script

echo "Starting network subsystems..."

# Start the inet system
if [ ! -f /etc/coyote/coyote.conf ]; then
	echo
	echo "-------------------------ERROR--------------------------"
	echo "This Coyote boot disk does not appear to have been"
	echo "properly configured.  The network subsystem can not be"
	echo "configured.  Please rerun the Coyote Disk Creator."
	echo "--------------------------------------------------------"
	echo
	exit
fi

# Ensure basic filesystem sanity
chmod 755 /
chmod 1777 /tmp

# Load the coyote configuration file
. /etc/coyote/coyote.conf
CONFIG_LOADED=YES

# Configure the root password
if [ ! -z "$ADMIN_AUTH" ]; then
    if [ -r /etc/shadow.tmp ]; then
	rm /etc/shadow.tmp
    fi
    touch /etc/shadow.tmp
    chown root.root /etc/shadow.tmp
    chmod 600 /etc/shadow.tmp
    echo "root:\$1\$\$${ADMIN_AUTH}:10091:0:99999:7:::" >> /etc/shadow.tmp
    grep -v root: /etc/shadow >> /etc/shadow.tmp
    rm /etc/shadow
    mv /etc/shadow.tmp /etc/shadow
fi

# Check for the SSH host keys
if [ ! -r /etc/dropbear_dss_host_key ]; then
    /usr/sbin/ssh-keygen -t dss -f /etc/dropbear_dss_host_key
    NEW_KEYS=YES
    touch /tmp/need.save
fi
if [ ! -r /etc/dropbear_rsa_host_key ]; then
    /usr/sbin/ssh-keygen -t rsa -f /etc/dropbear_rsa_host_key
    NEW_KEYS=YES
    touch /tmp/need.save
fi

# Set the system clock
if [ -z "$TZ" ]; then
	TZ="$(cat /etc/timezone)"
	echo "TZ=$TZ" >> /etc/coyote/coyote.conf
else
	echo "$TZ" > /etc/timezone
fi
cp /etc/timezone /etc/TZ
export TZ

# Set the clock using bios
if [ -x /sbin/hwclock ]; then
	/sbin/hwclock -s -l
fi

# System loggers
SYSLOG_OPTS="-m 0 -C "
if [ ! -z "$LOGGING_HOST" ]; then
	SYSLOG_OPTS="$SYSLOG_OPTS -L -R $LOGGING_HOST"
	# If remote logging is requested, delay until after the network
	# is up
fi

#Create the wellcome screen
. /usr/sbin/mkissue.sh

# Start the network
. /etc/rc.d/rc.inet

# Start any additional packages that were added
echo "Starting addon packages..."
SAVEDIR=`pwd`
cd /etc/rc.d/pkgs
for RCS in `ls rc.*`; do
	if [ -x $RCS ]; then
		. /etc/rc.d/pkgs/$RCS
	fi
done
cd $SAVEDIR

echo "Starting local packages..."
# Start any misc local commands
if [ -x /etc/rc.d/rc.local ]; then
	. /etc/rc.d/rc.local
fi

if [ "$NEW_KEYS" = "YES" ]; then
	/usr/sbin/lrcfg.back etc
fi
