#!/bin/sh
. /var/http/web-functions
. /etc/coyote/coyote.conf
. /tmp/netsubsys.state
if [ -f /etc/dhcpc/$IF_INET.info ] ; then
  . /etc/dhcpc/$IF_INET.info
  eval `ipcalc -m $dhcp_ip/$dhcp_mask`
fi
cl_header2 "Coyote Linux - $MWE"
VERSION=`cat /var/lib/lrpkg/root.version`
KERNEL=`uname -r`
MACHINE="`uname -m` `uname -p`"
HOST=`hostname`
NOW=`date`
UPTIME=`uptime`
LOAD=`cat /proc/loadavg`
LAST1=`echo $LOAD | cut -f 1 -d ' '`
LAST5=`echo $LOAD | cut -f 2 -d ' '`
LAST15=`echo $LOAD | cut -f 3 -d ' '`
MEMTOTAL=`free | grep Mem | sed s/\ */#/g | cut -f 3 -d '#'`
MEMUSED=`free | grep Mem | sed s/\ */#/g | cut -f 4 -d '#'`
MEMFREE=`free | grep Mem | sed s/\ */#/g | cut -f 5 -d '#'`
PERCUSED=$((MEMUSED*100/MEMTOTAL))
PERCFREE=$((100-$PERCUSED))

if [ "$INETTYPE" = "ETHERNET_DHCP" ] ; then
  if [ -e "/etc/dhcpc/$IF_INET.info" ] ; then
    . /etc/dhcpc/$IF_INET.info
  fi
fi
[ -z "$DOMAINNAME" -a -n "$dhcp_domain" ] && DOMAINNAME="$dhcp_domain"
[ -z "$DOMAINNAME" -a -n "$DHCPD_DOMAIN" ] && DOMAINNAME="$DHCPD_DOMAIN"
[ -z "$DOMAINNAME" ] && DOMAINNAME="localdomain"
DNSSTATUS=$Abk
[ "$USE_DNS_CACHE" = "YES" ] && DNSSTATUS=$Abj
DHCPSTATUS=$Abk
[ "$DHCPSERVER" = "YES" ] && DHCPSTATUS=$Abj
SSHSTATUS=$Abj
[ "$ENABLE_EXTERNAL_SSH" = "NO" ] && SSHSTATUS=$Abl
[ -z "$SSH_PORT" ] && SSH_PORT=22
WEBADMSTATUS=$Abj
[ "$ENABLE_WEBADMIN" = "NO" ] && WEBADMSTATUS=$Abk
[ -z "$WEBADMIN_PORT" ] && WEBADMIN_PORT=8180
[ "$INETTYPE" = "PPP" ] && INTERNET_TYPE="$Abp"
[ "$INETTYPE" = "PPPOE" ] && INTERNET_TYPE="$Abq"
[ "$INETTYPE" = "ETHERNET_STATIC" ] && INTERNET_TYPE="$Abr"
[ "$INETTYPE" = "ETHERNET_DHCP" ] && INTERNET_TYPE="$Abs"
[ "$LOCAL_UP" = "UP" ] && LLOCAL_UP=$Abm
[ "$LOCAL_UP" = "DOWN" ] && LLOCAL_UP=$Abn
[ "$LOCAL_UP" = "READY" ] && LLOCAL_UP=$Abo
[ "$INET_UP" = "UP" ] && LINET_UP=$Abm
[ "$INET_UP" = "DOWN" ] && LINET_UP=$Abn
[ "$INET_UP" = "READY" ] && LINET_UP=$Abo
[ "$DMZ_UP" = "UP" ] && LDMZ_UP=$Abm
[ "$DMZ_UP" = "DOWN" ] && LDMZ_UP=$Abn
[ "$DMZ_UP" = "READY" ] && LDMZ_UP=$Abo

PPPIP=`getifaddr ppp0`
GW=`iproute show | grep default | cut -f 3 -d ' '`
get_color() {
  if [ "$1" = "$Abm" ] ; then
    echo green
  elif [ "$1" = "$Abn" ] ; then
    echo red
  elif [ "$1" = "$Abj" ] ; then
    echo green
  elif [ "$1" = "$Abk" ] ; then
    echo red
  else
    echo "#ffcc44"
  fi
}
cat << CLEOF
<center>
  <table border="0" width="100%">
    <tr>
      <td colspan=4 align=center bgcolor="#000080">
      <font color=white><b>$Agi</b></td>
    </tr>
    <tr>
      <td width=50% colspan=2 bgcolor="#C0C0C0" align="right"><b>Coyote Linux - $Avs</b></td>
      <td width=50% colspan=2 bgcolor="#EDECEC">$VERSION</td>
    </tr>
    <tr>
      <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Ahs</b></td>
      <td colspan=2 bgcolor="#EDECEC">$HOST</td></tr>
    <tr>
      <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Adn</b></td>
      <td colspan=2 bgcolor="#EDECEC">$DOMAINNAME</td>
    </tr>
    <tr>
      <td colspan=4 align=center bgcolor="#000080">
      <font color=white><b>$Ans - $Ani</b></td></tr>
    </tr>
CLEOF
if [ "$INETTYPE" = "ETHERNET_STATIC" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ast</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC><font color=`get_color $LINET_UP`><b>$LINET_UP</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ait</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$INTERNET_TYPE</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Aei</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$IPADDR</td></tr>"
  if [ -n "$IPADDR2" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$And $Aei</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$IPADDR2/$NETMASK2</td></tr>"
  fi
  if [ -n "$IPADDR3" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ard $Aei</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$IPADDR3/$NETMASK3</td></tr>"
  fi
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Anm</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$NETMASK</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Agt</b></td>"
  echo "<td width=25% bgcolor=#EDECEC>$GATEWAY</td>"
  echo "<td width=25% bgcolor=#EDECEC>[ <a href=diags.cgi?COMMAND=/usr/sbin/gateway.test><u>$Abf</u></a> ]</td></tr>"
fi
if [ "$INETTYPE" = "ETHERNET_DHCP" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ast</b></td>"
  echo "<td width=25% bgcolor=#EDECEC><font color=`get_color $LINET_UP`><b>$LINET_UP</td>"
  echo "<td width=25% bgcolor=#EDECEC>[ <a href=diags.cgi?COMMAND=/usr/sbin/dhcp.release><u>$Abh</u></a>&nbsp; |&nbsp;"
  echo "<a href=diags.cgi?COMMAND=/usr/sbin/dhcp.renew><u>$Abi</u></a> ]</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ait</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$INTERNET_TYPE</td></tr>"
  if [ -n "$dhcp_ip" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Aei</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$dhcp_ip</td>"
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Anm</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$NETMASK</td></tr>"
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Agt</b></td>"
    echo "<td width=25% bgcolor=#EDECEC>$dhcp_router</td>"
    echo "<td width=25% bgcolor=#EDECEC>[ <a href=diags.cgi?COMMAND=/usr/sbin/gateway.test><u>$Abf</u></a> ]</td></tr>"
  fi
fi
if [ "$INETTYPE" = "PPPOE" -o "$INETTYPE" = "PPP" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ast</b></td>"
  echo "<td width=25% bgcolor=#EDECEC><font color=`get_color $LINET_UP`><b>$LINET_UP</td>"
  echo "<td width=25% bgcolor=#EDECEC>[ <a href=dial-ppp.cgi><u>$Mdl</u></a>&nbsp; |&nbsp;"
  echo "<a href=hangup-ppp.cgi><u>$Mhg</u></a> ]</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ait</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$INTERNET_TYPE</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Aei</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$PPPIP</td></tr>"
  if [ -n "$CONNECTTIME" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Acs</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$CONNECTTIME</td></tr>"
  fi
  if [ -n "$CONNECTSTRING" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Act</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$CONNECTSTRING</td></tr>"
  fi
  if [ -n "$GW" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Agt</b></td>"
    echo "<td width=25% bgcolor=#EDECEC>$GW</td>"
    echo "<td width=25% bgcolor=#EDECEC>[ <a href=diags.cgi?COMMAND=/usr/sbin/gateway.test><u>$Abf</u></a> ]</td></tr>"
  fi
fi

echo "<tr><td colspan=4 align=center bgcolor=#000080><font color=white><b>$Ans - $Aln</b></td></tr>"
echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ast</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC><font color=`get_color $LLOCAL_UP`><b>$LLOCAL_UP</td></tr>"
echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ali</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC>$LOCAL_IPADDR</td></tr>"
if [ -n "$LOCAL_IPADDR2" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$And $Ali</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$LOCAL_IPADDR2 / $LOCAL_NETMASK2</td></tr>"
fi
if [ -n "$LOCAL_IPADDR3" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ard $Ali</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$LOCAL_IPADDR3 / $LOCAL_NETMASK3</td></tr>"
fi
echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Anm</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC>$LOCAL_NETMASK</td></tr>"
echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Abc</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC>$LOCAL_BROADCAST</td></tr>"

if [ -n "$DMZ_UP" ] ; then
  echo "<tr><td colspan=4 align=center bgcolor=#000080><font color=white><b>$Ans - $Adz</b></td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ast</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC><font color=`get_color $LDMZ_UP`><b>$LDMZ_UP</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>DMZ $Aip</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$DMZ_IPADDR</td></tr>"
  if [ -n "$DMZ_IPADDR2" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$And DMZ $Aip</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$DMZ_IPADDR2 / $DMZ_NETMASK2</td></tr>"
  fi
  if [ -n "$DMZ_IPADDR3" ] ; then
    echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ard DMZ $Aip</b></td>"
    echo "<td colspan=2 bgcolor=#EDECEC>$DMZ_IPADDR3 / $DMZ_NETMASK3</td></tr>"
  fi
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Anm</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$DMZ_NETMASK</td></tr>"
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Abc</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>$DMZ_BROADCAST</td></tr>"
fi

echo "<tr><td colspan=4 align=center bgcolor=#000080><font color=white><b>$Adi</b></td></tr>"
if [ -e "/tmp/realdns1" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Apn</b></td>"
  echo "<td width=25% bgcolor=#EDECEC>`cat /tmp/realdns1`</td>"
  echo "<td width=25% bgcolor=#EDECEC>[ <a href=diags.cgi?COMMAND=/usr/sbin/dns.test><u>$Abg</u></a> ]</td></tr>"
fi
if [ -e "/tmp/realdns2" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Asn</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>`cat /tmp/realdns2`</td></tr>"
fi
if [ -e "/tmp/realdns3" ] ; then
  echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Atn</b></td>"
  echo "<td colspan=2 bgcolor=#EDECEC>`cat /tmp/realdns3`</td></tr>"
fi

echo "<tr><td colspan=4 align=center bgcolor=#000080><font color=white><b>$Asv</b></td></tr>"
echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Adc</b></td>"
echo "<td width=25% bgcolor=#EDECEC><font color=`get_color $DNSSTATUS`>$DNSSTATUS</td>"
echo "<td width=25% bgcolor=#EDECEC>"
[ "$DNSSTATUS" = "$Abj" ] && echo "[ <a href=diags.cgi?COMMAND=/etc/rc.d/rc.dnsmasq><u>$Fay</u></a> ]"
echo "&nbsp;</td></tr>"

echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ads</b></td>"
echo "<td width=25% bgcolor=#EDECEC><font color=`get_color $DHCPSTATUS`>$DHCPSTATUS</td>"
echo "<td width=25% bgcolor=#EDECEC>"
[ "$DHCPSTATUS" = "$Abj" ] && echo "[ <a href=diags.cgi?COMMAND=/etc/rc.d/rc.dnsmasq><u>$Fay</u></a> ]"
echo "&nbsp;</td></tr>"

echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Ass</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC><font color=`get_color $SSHSTATUS`>$SSHSTATUS</font>"
[ "$SSHSTATUS" != "Disabled" ] && echo " ($Abe $SSH_PORT)"
echo "</td></tr>"

echo "<tr><td colspan=2 bgcolor=#C0C0C0 align=right><b>$Awa</b></td>"
echo "<td colspan=2 bgcolor=#EDECEC><font color=`get_color $WEBADMSTATUS`>$WEBADMSTATUS</font>"
[ "$WEBADMSTATUS" = "$Abj" ] && echo " ($Abe $WEBADMIN_PORT)"
echo "</td></tr>"

cat << CLEOF
<tr>
  <td colspan=4 align=center bgcolor="#000080">
  <font color=white><b>$Asi</b></td>
</tr>   
<tr>
  <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Akv</b></td>
  <td colspan=2 bgcolor="#EDECEC">$KERNEL</td>
</tr>
<tr>
  <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Amc</b></td>
  <td colspan=2 bgcolor="#EDECEC">$MACHINE</td>
</tr>
<tr>
  <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Adt</b></td>
  <td colspan=2 bgcolor="#EDECEC">$NOW</td>
</tr>
<tr>
  <td colspan=2 bgcolor="#C0C0C0" align="right"><b>$Aup</b></td>
  <td colspan=2 bgcolor="#EDECEC">$UPTIME</td>
</tr>
<tr>
  <td rowspan=3 bgcolor="#C0C0C0" align="right"><b>$Ala</b></td>
  <td bgcolor="#C0C0C0" align="right"><b>$Abb</b></td>
  <td colspan=2 bgcolor="#EDECEC">$LAST1</td>
</tr>
<tr>
  <td bgcolor="#C0C0C0" align="right"><b>$Als 5 $Amn</b></td>
  <td colspan=2 bgcolor="#EDECEC">$LAST5</td>
</tr>
<tr>
  <td bgcolor="#C0C0C0" align="right"><b>$Als 15 $Amn</b></td>
  <td colspan=2 bgcolor="#EDECEC">$LAST15</td>
</tr>
<tr>
  <td rowspan=3 bgcolor="#C0C0C0" align="right"><b>$Amu</b></td>
  <td bgcolor="#C0C0C0" align="right"><b>$Abd</b></td>
  <td colspan=2 bgcolor="#EDECEC">$MEMTOTAL (100%)</td>
</tr>
<tr>
  <td bgcolor="#C0C0C0" align="right"><b>$Aus</b></td>
  <td colspan=2 bgcolor="#EDECEC">$MEMUSED ($PERCUSED%)</td>
</tr>
<tr>
  <td bgcolor="#C0C0C0" align="right"><b>$Afr</b></td>
  <td colspan=2 bgcolor="#EDECEC">$MEMFREE ($PERCFREE%)</td>
</tr>
CLEOF
echo "<tr></table></center>"
cl_footer2
